@@ -23,11 +23,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
+import aws_cdk.core
+
 
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-waf.CfnByteMatchSet"):
@@ -38,7 +37,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::ByteMatchSet
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, byte_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]=None) -> None:
         """Create a new ``AWS::WAF::ByteMatchSet``.
 
         :param scope: - scope in which this resource is defined.
@@ -109,12 +108,12 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
     @jsii.member(jsii_name="byteMatchTuples")
-    def byte_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]]:
+    def byte_match_tuples(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -123,7 +122,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
         return jsii.get(self, "byteMatchTuples")
 
     @byte_match_tuples.setter
-    def byte_match_tuples(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]]):
+    def byte_match_tuples(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]) -> None:
         jsii.set(self, "byteMatchTuples", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnByteMatchSet.ByteMatchTupleProperty", jsii_struct_bases=[], name_mapping={'field_to_match': 'fieldToMatch', 'positional_constraint': 'positionalConstraint', 'text_transformation': 'textTransformation', 'target_string': 'targetString', 'target_string_base64': 'targetStringBase64'})
@@ -248,7 +247,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnByteMatchSetProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'byte_match_tuples': 'byteMatchTuples'})
 class CfnByteMatchSetProps():
-    def __init__(self, *, name: str, byte_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]]=None) -> None:
+    def __init__(self, *, name: str, byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]=None) -> None:
         """Properties for defining a ``AWS::WAF::ByteMatchSet``.
 
         :param name: ``AWS::WAF::ByteMatchSet.Name``.
@@ -272,7 +271,7 @@ class CfnByteMatchSetProps():
         return self._values.get('name')
 
     @builtins.property
-    def byte_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]]:
+    def byte_match_tuples(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -299,7 +298,7 @@ class CfnIPSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::IPSet
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, ip_set_descriptors: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]=None) -> None:
         """Create a new ``AWS::WAF::IPSet``.
 
         :param scope: - scope in which this resource is defined.
@@ -370,12 +369,12 @@ class CfnIPSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
     @jsii.member(jsii_name="ipSetDescriptors")
-    def ip_set_descriptors(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]]:
+    def ip_set_descriptors(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]:
         """``AWS::WAF::IPSet.IPSetDescriptors``.
 
         see
@@ -384,7 +383,7 @@ class CfnIPSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "ipSetDescriptors")
 
     @ip_set_descriptors.setter
-    def ip_set_descriptors(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]]):
+    def ip_set_descriptors(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]) -> None:
         jsii.set(self, "ipSetDescriptors", value)
 
     @jsii.interface(jsii_type="@aws-cdk/aws-waf.CfnIPSet.IPSetDescriptorProperty")
@@ -448,7 +447,7 @@ class CfnIPSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnIPSetProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'ip_set_descriptors': 'ipSetDescriptors'})
 class CfnIPSetProps():
-    def __init__(self, *, name: str, ip_set_descriptors: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]]]=None) -> None:
+    def __init__(self, *, name: str, ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]]=None) -> None:
         """Properties for defining a ``AWS::WAF::IPSet``.
 
         :param name: ``AWS::WAF::IPSet.Name``.
@@ -472,7 +471,7 @@ class CfnIPSetProps():
         return self._values.get('name')
 
     @builtins.property
-    def ip_set_descriptors(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]]]:
+    def ip_set_descriptors(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]]:
         """``AWS::WAF::IPSet.IPSetDescriptors``.
 
         see
@@ -499,7 +498,7 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::Rule
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, metric_name: str, name: str, predicates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, metric_name: str, name: str, predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]=None) -> None:
         """Create a new ``AWS::WAF::Rule``.
 
         :param scope: - scope in which this resource is defined.
@@ -571,7 +570,7 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         return jsii.get(self, "metricName")
 
     @metric_name.setter
-    def metric_name(self, value: str):
+    def metric_name(self, value: str) -> None:
         jsii.set(self, "metricName", value)
 
     @builtins.property
@@ -585,12 +584,12 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
     @jsii.member(jsii_name="predicates")
-    def predicates(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]]:
+    def predicates(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]:
         """``AWS::WAF::Rule.Predicates``.
 
         see
@@ -599,7 +598,7 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         return jsii.get(self, "predicates")
 
     @predicates.setter
-    def predicates(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]]):
+    def predicates(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]) -> None:
         jsii.set(self, "predicates", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnRule.PredicateProperty", jsii_struct_bases=[], name_mapping={'data_id': 'dataId', 'negated': 'negated', 'type': 'type'})
@@ -659,7 +658,7 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnRuleProps", jsii_struct_bases=[], name_mapping={'metric_name': 'metricName', 'name': 'name', 'predicates': 'predicates'})
 class CfnRuleProps():
-    def __init__(self, *, metric_name: str, name: str, predicates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]]]=None) -> None:
+    def __init__(self, *, metric_name: str, name: str, predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]]=None) -> None:
         """Properties for defining a ``AWS::WAF::Rule``.
 
         :param metric_name: ``AWS::WAF::Rule.MetricName``.
@@ -694,7 +693,7 @@ class CfnRuleProps():
         return self._values.get('name')
 
     @builtins.property
-    def predicates(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]]]:
+    def predicates(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]]:
         """``AWS::WAF::Rule.Predicates``.
 
         see
@@ -792,7 +791,7 @@ class CfnSizeConstraintSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, js
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -806,7 +805,7 @@ class CfnSizeConstraintSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, js
         return jsii.get(self, "sizeConstraints")
 
     @size_constraints.setter
-    def size_constraints(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]]]):
+    def size_constraints(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]]]) -> None:
         jsii.set(self, "sizeConstraints", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnSizeConstraintSet.FieldToMatchProperty", jsii_struct_bases=[], name_mapping={'type': 'type', 'data': 'data'})
@@ -971,7 +970,7 @@ class CfnSqlInjectionMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::SqlInjectionMatchSet
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, sql_injection_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]=None) -> None:
         """Create a new ``AWS::WAF::SqlInjectionMatchSet``.
 
         :param scope: - scope in which this resource is defined.
@@ -1042,12 +1041,12 @@ class CfnSqlInjectionMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
     @jsii.member(jsii_name="sqlInjectionMatchTuples")
-    def sql_injection_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]]:
+    def sql_injection_match_tuples(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]:
         """``AWS::WAF::SqlInjectionMatchSet.SqlInjectionMatchTuples``.
 
         see
@@ -1056,7 +1055,7 @@ class CfnSqlInjectionMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
         return jsii.get(self, "sqlInjectionMatchTuples")
 
     @sql_injection_match_tuples.setter
-    def sql_injection_match_tuples(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]]):
+    def sql_injection_match_tuples(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]) -> None:
         jsii.set(self, "sqlInjectionMatchTuples", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnSqlInjectionMatchSet.FieldToMatchProperty", jsii_struct_bases=[], name_mapping={'type': 'type', 'data': 'data'})
@@ -1148,7 +1147,7 @@ class CfnSqlInjectionMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnSqlInjectionMatchSetProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'sql_injection_match_tuples': 'sqlInjectionMatchTuples'})
 class CfnSqlInjectionMatchSetProps():
-    def __init__(self, *, name: str, sql_injection_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]]]=None) -> None:
+    def __init__(self, *, name: str, sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]]=None) -> None:
         """Properties for defining a ``AWS::WAF::SqlInjectionMatchSet``.
 
         :param name: ``AWS::WAF::SqlInjectionMatchSet.Name``.
@@ -1172,7 +1171,7 @@ class CfnSqlInjectionMatchSetProps():
         return self._values.get('name')
 
     @builtins.property
-    def sql_injection_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]]]:
+    def sql_injection_match_tuples(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]]:
         """``AWS::WAF::SqlInjectionMatchSet.SqlInjectionMatchTuples``.
 
         see
@@ -1199,7 +1198,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::WebACL
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, default_action: typing.Union["WafActionProperty", aws_cdk.core.IResolvable], metric_name: str, name: str, rules: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, default_action: typing.Union["WafActionProperty", aws_cdk.core.IResolvable], metric_name: str, name: str, rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]=None) -> None:
         """Create a new ``AWS::WAF::WebACL``.
 
         :param scope: - scope in which this resource is defined.
@@ -1272,7 +1271,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "defaultAction")
 
     @default_action.setter
-    def default_action(self, value: typing.Union["WafActionProperty", aws_cdk.core.IResolvable]):
+    def default_action(self, value: typing.Union["WafActionProperty", aws_cdk.core.IResolvable]) -> None:
         jsii.set(self, "defaultAction", value)
 
     @builtins.property
@@ -1286,7 +1285,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "metricName")
 
     @metric_name.setter
-    def metric_name(self, value: str):
+    def metric_name(self, value: str) -> None:
         jsii.set(self, "metricName", value)
 
     @builtins.property
@@ -1300,12 +1299,12 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
     @jsii.member(jsii_name="rules")
-    def rules(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]]:
+    def rules(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]:
         """``AWS::WAF::WebACL.Rules``.
 
         see
@@ -1314,12 +1313,12 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "rules")
 
     @rules.setter
-    def rules(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]]):
+    def rules(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]) -> None:
         jsii.set(self, "rules", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnWebACL.ActivatedRuleProperty", jsii_struct_bases=[], name_mapping={'priority': 'priority', 'rule_id': 'ruleId', 'action': 'action'})
     class ActivatedRuleProperty():
-        def __init__(self, *, priority: jsii.Number, rule_id: str, action: typing.Optional[typing.Union[typing.Optional["CfnWebACL.WafActionProperty"], typing.Optional[aws_cdk.core.IResolvable]]]=None) -> None:
+        def __init__(self, *, priority: jsii.Number, rule_id: str, action: typing.Optional[typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]]=None) -> None:
             """
             :param priority: ``CfnWebACL.ActivatedRuleProperty.Priority``.
             :param rule_id: ``CfnWebACL.ActivatedRuleProperty.RuleId``.
@@ -1353,7 +1352,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
             return self._values.get('rule_id')
 
         @builtins.property
-        def action(self) -> typing.Optional[typing.Union[typing.Optional["CfnWebACL.WafActionProperty"], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def action(self) -> typing.Optional[typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]]:
             """``CfnWebACL.ActivatedRuleProperty.Action``.
 
             see
@@ -1406,7 +1405,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnWebACLProps", jsii_struct_bases=[], name_mapping={'default_action': 'defaultAction', 'metric_name': 'metricName', 'name': 'name', 'rules': 'rules'})
 class CfnWebACLProps():
-    def __init__(self, *, default_action: typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable], metric_name: str, name: str, rules: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]]=None) -> None:
+    def __init__(self, *, default_action: typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable], metric_name: str, name: str, rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]=None) -> None:
         """Properties for defining a ``AWS::WAF::WebACL``.
 
         :param default_action: ``AWS::WAF::WebACL.DefaultAction``.
@@ -1452,7 +1451,7 @@ class CfnWebACLProps():
         return self._values.get('name')
 
     @builtins.property
-    def rules(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]]:
+    def rules(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]:
         """``AWS::WAF::WebACL.Rules``.
 
         see
@@ -1550,7 +1549,7 @@ class CfnXssMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -1564,7 +1563,7 @@ class CfnXssMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "xssMatchTuples")
 
     @xss_match_tuples.setter
-    def xss_match_tuples(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]]]):
+    def xss_match_tuples(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]]]) -> None:
         jsii.set(self, "xssMatchTuples", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnXssMatchSet.FieldToMatchProperty", jsii_struct_bases=[], name_mapping={'type': 'type', 'data': 'data'})
