@@ -8,10 +8,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
+import aws_cdk.core._jsii
+import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-waf", "1.40.0", __name__[0:-6], "aws-waf@1.40.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-waf", "1.45.0", __name__[0:-6], "aws-waf@1.45.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
